import { useMutation, useQueryClient } from '@tanstack/react-query';

import { IUserProfile } from '@/models/user';

import { IUpdateProfileDTO, usersApi } from './api';

// TODO: reload users / optimistic update

export const useUpdateProfile = () => {
  const queryClient = useQueryClient();
  const mutation = useMutation({
    mutationKey: ['update-profile'],
    mutationFn: usersApi.updateProfile,
    onSuccess: () => queryClient.invalidateQueries({ queryKey: [usersApi.baseKey] })
  });
  return {
    updateProfile: (data: IUpdateProfileDTO, onSuccess?: (newUser: IUserProfile) => void) =>
      mutation.mutate(data, { onSuccess: response => onSuccess?.(response.data as IUserProfile) }),
    isPending: mutation.isPending,
    error: mutation.error,
    reset: mutation.reset
  };
};
